# -*- coding: utf-8 -*-
# @Time    : 2022/12/8 20:01
# @Author  : vicissitude
import timeworker

time_str = '去年13月'
print(timeworker.parse(time_str))